@@ -583,6 +583,18 @@ def matrix2str(mat, space=''):
 			string += str(m)
 	return string
 
+@appendAll
+@addBuiltins
+class LoopBack(object):
+	def _back(*args, **kwargs):
+		pass
+
+	def __getattribute__(self, key):
+		try:
+			return object.__getattribute__(self, key)
+		except:
+			return self._back
+
 @appendAll
 @addBuiltins
 class Database(object):
@@ -1550,6 +1562,14 @@ class ProtString(str):
 				out = str(self)
 		return out
 
+	@property
+	def type(self):
+		return self.split('.')[-1].lower()
+
+	@property
+	def has_type(self):
+		return len(self.split('.')) > 1
+
 	def extract(self):
 		splittedList = self.split(',')
 		splittedDict = {}
